@@ -16,9 +16,13 @@
 #' @export
 GetproteinNetwork <- function(ProteinAccList , directorypath = NULL)
 {
+  LogFile <- paste0(directorypath,"NetworkLog.txt")
+  
   pdf(paste0(directorypath , "/","Protin Network.pdf"))
   baseUrl <- "https://string-db.org/api/image/network?identifiers="
   Accessions <- NULL
+  cat(paste0("Run started at: " , date), file = LogFile, append = TRUE, sep = "\n")
+  
   for (identifier in ProteinAccList)
   {
     ProteinString <- paste0(baseUrl , identifier)
@@ -32,6 +36,7 @@ GetproteinNetwork <- function(ProteinAccList , directorypath = NULL)
       title(list(paste0(identifier ,":" ,  ProteinName),cex = 0.4, font = 1))
       Accessions <- c(Accessions , identifier);
     }else{
+      cat(paste0(identifier , " Not Found on Stringdb"), file = LogFile, append = TRUE, sep = "\n")
       print(paste0(identifier , " Not Found on Stringdb"))
     }
   }
@@ -43,4 +48,5 @@ GetproteinNetwork <- function(ProteinAccList , directorypath = NULL)
   title(list("Whole Protein Network", cex = 1,
              col = "black", font = 1))
   dev.off()
+  cat(paste0("Run Finished at: " , date), file = LogFile, append = TRUE, sep = "\n")
 }
